use crate::jira_config::JiraConfig;
use crate::types::issue::{display_issues_json, display_issues_pretty};

pub async fn exec(json: bool, jql: &str) -> Result<(), Box<dyn std::error::Error>> {
    let config = JiraConfig::load().map_err(|e| format!("Configuration error: {}", e))?;
    if !json {
        println!("Searching for issues...");
    }

    match crate::jql::run(&config, jql).await {
        Ok(response) => {
            if json {
                if response.issues.is_empty() {
                    println!("[]");
                } else {
                    display_issues_json(&response.issues)?;
                }
            } else if response.issues.is_empty() {
                println!("No results found for query.");
            } else {
                display_issues_pretty(&response.issues)?;
                println!("Total issues: {}", response.total);
            }
        }
        Err(e) => {
            eprintln!("Error fetching issues: {}", e);
            std::process::exit(1);
        }
    }

    Ok(())
}
